### Name: TwslmSpikeWeight
### Title: Normalization of cDNA microarray data using spike and spot
###   quality information in the two-way semi-linear model (TW-SLM)
### Aliases: TwslmSpikeWeight spike robust.spike BlockByBlock.spike
### Keywords: robust smooth nonparametric

### ** Examples


## The example used in the paper Wang et al. (2007) will be used to 
## demonstrate utilization of the developed package for normlization of cDNA 
## microarray data by incorporating spike and spot quality information.

## load data used for the calculation

#require(TwslmSpikeWeight)

data(HU,"HUweightdata")

## a function to calculate weights of spots

ratioweight <- function(RF,RB,SDRF,SDRB,GF,GB,SDGF,SDGB,NF,NB){

  weight <- 1/((SDRF^2/NF+SDRB^2/NB)/(RF-RB)^2+(SDGF^2/NF+SDGB^2/NB)/(GF-GB)^2)

  return(weight)
}

## spikes ids
zerospike <- c("01-NBB-f-02","02-NAP-a-01","03-NAP-a-05","04-NAP-a-09","05-NXEg-e-10",
"06-NXEg-h-07","07-NBB-h-08","08-NBB-f-05","09-NAP-b-02","10-NS8W-d-02","11-NS8W-c-10",
"12-NAP-c-05","13-NAP-b-06","14-NAP-b-08","15-NAP-d-08","16-NAP-c-02","17-NBB-g-12",
"18-NAP-d-03","19-NAP-d-06","20-NXEg-h-06","21-NAP-c-08","22-NBB-h-07","23-NBB-e-09",
"24-NAP-d-09","25-NAP-b-09","26-NBB-f-08","SC1","SC3","SC5")

## calculate weights

allw <- ratioweight(RF=HUweightdata$RF,RB=HUweightdata$RB,SDRF=HUweightdata$SDRF,
  SDRB=HUweightdata$SDRB,GF=HUweightdata$GF,GB=HUweightdata$GB,SDGF=HUweightdata$SDGF,
  SDGB=HUweightdata$SDGB,NF=HUweightdata$NF,NB=HUweightdata$NB)

HUid <- HU$HUid
HUratio <- HU$HUratio
HUint <- HU$HUint
HUslide <- HU$HUslide
HUblock <- HU$HUblock

flag <- match(HUid,zerospike,nomatch=0)>0

## calculate weights

w <- allw[!flag]
huid <- HUid[!flag]
hurt <- HUratio[!flag]
huint <- HUint[!flag]
husld <- HUslide[!flag]
hublk <- HUblock[!flag]

##spikes information

sw <- allw[flag]
shuid <- HUid[flag]
shurt <- HUratio[flag]
shuint <- HUint[flag]
shusld <- HUslide[flag]
shublk <- HUblock[flag]

## spike,robust,weight;

huSRW <- TwslmSpikeWeight(sld=husld,geneid=huid,rt=hurt,intn=huint, weight=w,
 s.sld=shusld,s.geneid=shuid,s.rt=shurt,s.intn=shuint,s.weight=sw,s.constant=0.0,
 df=12,degree=3,block.norm=FALSE,robust=TRUE,robust.name="Tukey", scale.constant=2.5,
 weight.constant=4.685,ibeta=NULL,iscale=NULL,tol=0.0001)

a <- huSRW$slide
b <- huSRW$spike.slide
rr <- huSRW$ratio[a==1]
intt <- huSRW$intensity[a==1]
ff <- huSRW$bfit[a==1]
ii <- order(intt)

plot(intt,rr,xlim=c(0,16))
lines(intt[ii],ff[ii],col="red")
points(huSRW$spike.intensity[b==1],huSRW$spike.ratio[b==1],col="blue")

##zerospike estimates( mean median, sd)

zerospikemeanR <- aggregate(huSRW$spike.ratio-huSRW$spike.bfit,by=list(huSRW$spike.id),mean)
spikemeanR <- mean(2^zerospikemeanR$x)
spikemedianR <- median(2^zerospikemeanR$x)
spikesdR <- sd(2^zerospikemeanR$x)




